/****************************************************************************
** Meta object code from reading C++ file 'gpgproc.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qca-2.3.10/plugins/qca-gnupg/gpgproc/gpgproc.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'gpgproc.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12gpgQCAPlugin7GPGProcE_t {};
} // unnamed namespace

template <> constexpr inline auto gpgQCAPlugin::GPGProc::qt_create_metaobjectdata<qt_meta_tag_ZN12gpgQCAPlugin7GPGProcE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "gpgQCAPlugin::GPGProc",
        "error",
        "",
        "gpgQCAPlugin::GPGProc::Error",
        "finished",
        "exitCode",
        "readyReadStdout",
        "readyReadStderr",
        "readyReadStatusLines",
        "bytesWrittenStdin",
        "bytes",
        "bytesWrittenAux",
        "bytesWrittenCommand",
        "debug",
        "str"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'error'
        QtMocHelpers::SignalData<void(gpgQCAPlugin::GPGProc::Error)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 1 },
        }}),
        // Signal 'finished'
        QtMocHelpers::SignalData<void(int)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 },
        }}),
        // Signal 'readyReadStdout'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'readyReadStderr'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'readyReadStatusLines'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'bytesWrittenStdin'
        QtMocHelpers::SignalData<void(int)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 10 },
        }}),
        // Signal 'bytesWrittenAux'
        QtMocHelpers::SignalData<void(int)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 10 },
        }}),
        // Signal 'bytesWrittenCommand'
        QtMocHelpers::SignalData<void(int)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 10 },
        }}),
        // Signal 'debug'
        QtMocHelpers::SignalData<void(const QString &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<GPGProc, qt_meta_tag_ZN12gpgQCAPlugin7GPGProcE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject gpgQCAPlugin::GPGProc::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12gpgQCAPlugin7GPGProcE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12gpgQCAPlugin7GPGProcE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12gpgQCAPlugin7GPGProcE_t>.metaTypes,
    nullptr
} };

void gpgQCAPlugin::GPGProc::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<GPGProc *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->error((*reinterpret_cast<std::add_pointer_t<gpgQCAPlugin::GPGProc::Error>>(_a[1]))); break;
        case 1: _t->finished((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->readyReadStdout(); break;
        case 3: _t->readyReadStderr(); break;
        case 4: _t->readyReadStatusLines(); break;
        case 5: _t->bytesWrittenStdin((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->bytesWrittenAux((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 7: _t->bytesWrittenCommand((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->debug((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (GPGProc::*)(gpgQCAPlugin::GPGProc::Error )>(_a, &GPGProc::error, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (GPGProc::*)(int )>(_a, &GPGProc::finished, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (GPGProc::*)()>(_a, &GPGProc::readyReadStdout, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (GPGProc::*)()>(_a, &GPGProc::readyReadStderr, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (GPGProc::*)()>(_a, &GPGProc::readyReadStatusLines, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (GPGProc::*)(int )>(_a, &GPGProc::bytesWrittenStdin, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (GPGProc::*)(int )>(_a, &GPGProc::bytesWrittenAux, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (GPGProc::*)(int )>(_a, &GPGProc::bytesWrittenCommand, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (GPGProc::*)(const QString & )>(_a, &GPGProc::debug, 8))
            return;
    }
}

const QMetaObject *gpgQCAPlugin::GPGProc::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *gpgQCAPlugin::GPGProc::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12gpgQCAPlugin7GPGProcE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int gpgQCAPlugin::GPGProc::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void gpgQCAPlugin::GPGProc::error(gpgQCAPlugin::GPGProc::Error _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void gpgQCAPlugin::GPGProc::finished(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void gpgQCAPlugin::GPGProc::readyReadStdout()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void gpgQCAPlugin::GPGProc::readyReadStderr()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void gpgQCAPlugin::GPGProc::readyReadStatusLines()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void gpgQCAPlugin::GPGProc::bytesWrittenStdin(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void gpgQCAPlugin::GPGProc::bytesWrittenAux(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void gpgQCAPlugin::GPGProc::bytesWrittenCommand(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void gpgQCAPlugin::GPGProc::debug(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}
QT_WARNING_POP
