/****************************************************************************
** Meta object code from reading C++ file 'qca_securelayer.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../qca-2.3.10/include/QtCrypto/qca_securelayer.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qca_securelayer.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3QCA11SecureLayerE_t {};
} // unnamed namespace

template <> constexpr inline auto QCA::SecureLayer::qt_create_metaobjectdata<qt_meta_tag_ZN3QCA11SecureLayerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QCA::SecureLayer",
        "readyRead",
        "",
        "readyReadOutgoing",
        "closed",
        "error"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'readyRead'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'readyReadOutgoing'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'closed'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'error'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SecureLayer, qt_meta_tag_ZN3QCA11SecureLayerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QCA::SecureLayer::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3QCA11SecureLayerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3QCA11SecureLayerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3QCA11SecureLayerE_t>.metaTypes,
    nullptr
} };

void QCA::SecureLayer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SecureLayer *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->readyRead(); break;
        case 1: _t->readyReadOutgoing(); break;
        case 2: _t->closed(); break;
        case 3: _t->error(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SecureLayer::*)()>(_a, &SecureLayer::readyRead, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SecureLayer::*)()>(_a, &SecureLayer::readyReadOutgoing, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (SecureLayer::*)()>(_a, &SecureLayer::closed, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (SecureLayer::*)()>(_a, &SecureLayer::error, 3))
            return;
    }
}

const QMetaObject *QCA::SecureLayer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QCA::SecureLayer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3QCA11SecureLayerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int QCA::SecureLayer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void QCA::SecureLayer::readyRead()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QCA::SecureLayer::readyReadOutgoing()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QCA::SecureLayer::closed()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QCA::SecureLayer::error()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
namespace {
struct qt_meta_tag_ZN3QCA3TLSE_t {};
} // unnamed namespace

template <> constexpr inline auto QCA::TLS::qt_create_metaobjectdata<qt_meta_tag_ZN3QCA3TLSE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QCA::TLS",
        "hostNameReceived",
        "",
        "certificateRequested",
        "peerCertificateAvailable",
        "handshaken"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'hostNameReceived'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'certificateRequested'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'peerCertificateAvailable'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'handshaken'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TLS, qt_meta_tag_ZN3QCA3TLSE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QCA::TLS::staticMetaObject = { {
    QMetaObject::SuperData::link<SecureLayer::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3QCA3TLSE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3QCA3TLSE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3QCA3TLSE_t>.metaTypes,
    nullptr
} };

void QCA::TLS::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TLS *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->hostNameReceived(); break;
        case 1: _t->certificateRequested(); break;
        case 2: _t->peerCertificateAvailable(); break;
        case 3: _t->handshaken(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TLS::*)()>(_a, &TLS::hostNameReceived, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TLS::*)()>(_a, &TLS::certificateRequested, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (TLS::*)()>(_a, &TLS::peerCertificateAvailable, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (TLS::*)()>(_a, &TLS::handshaken, 3))
            return;
    }
}

const QMetaObject *QCA::TLS::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QCA::TLS::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3QCA3TLSE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Algorithm"))
        return static_cast< Algorithm*>(this);
    return SecureLayer::qt_metacast(_clname);
}

int QCA::TLS::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = SecureLayer::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void QCA::TLS::hostNameReceived()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QCA::TLS::certificateRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QCA::TLS::peerCertificateAvailable()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QCA::TLS::handshaken()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
namespace {
struct qt_meta_tag_ZN3QCA4SASLE_t {};
} // unnamed namespace

template <> constexpr inline auto QCA::SASL::qt_create_metaobjectdata<qt_meta_tag_ZN3QCA4SASLE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QCA::SASL",
        "clientStarted",
        "",
        "clientInit",
        "clientInitData",
        "serverStarted",
        "nextStep",
        "stepData",
        "needParams",
        "QCA::SASL::Params",
        "params",
        "authCheck",
        "user",
        "authzid",
        "authenticated"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'clientStarted'
        QtMocHelpers::SignalData<void(bool, const QByteArray &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 }, { QMetaType::QByteArray, 4 },
        }}),
        // Signal 'serverStarted'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'nextStep'
        QtMocHelpers::SignalData<void(const QByteArray &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QByteArray, 7 },
        }}),
        // Signal 'needParams'
        QtMocHelpers::SignalData<void(const QCA::SASL::Params &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Signal 'authCheck'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 }, { QMetaType::QString, 13 },
        }}),
        // Signal 'authenticated'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SASL, qt_meta_tag_ZN3QCA4SASLE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QCA::SASL::staticMetaObject = { {
    QMetaObject::SuperData::link<SecureLayer::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3QCA4SASLE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3QCA4SASLE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3QCA4SASLE_t>.metaTypes,
    nullptr
} };

void QCA::SASL::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SASL *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->clientStarted((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[2]))); break;
        case 1: _t->serverStarted(); break;
        case 2: _t->nextStep((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1]))); break;
        case 3: _t->needParams((*reinterpret_cast<std::add_pointer_t<QCA::SASL::Params>>(_a[1]))); break;
        case 4: _t->authCheck((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 5: _t->authenticated(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SASL::*)(bool , const QByteArray & )>(_a, &SASL::clientStarted, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SASL::*)()>(_a, &SASL::serverStarted, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (SASL::*)(const QByteArray & )>(_a, &SASL::nextStep, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (SASL::*)(const QCA::SASL::Params & )>(_a, &SASL::needParams, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (SASL::*)(const QString & , const QString & )>(_a, &SASL::authCheck, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (SASL::*)()>(_a, &SASL::authenticated, 5))
            return;
    }
}

const QMetaObject *QCA::SASL::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QCA::SASL::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3QCA4SASLE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Algorithm"))
        return static_cast< Algorithm*>(this);
    return SecureLayer::qt_metacast(_clname);
}

int QCA::SASL::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = SecureLayer::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void QCA::SASL::clientStarted(bool _t1, const QByteArray & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void QCA::SASL::serverStarted()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QCA::SASL::nextStep(const QByteArray & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void QCA::SASL::needParams(const QCA::SASL::Params & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void QCA::SASL::authCheck(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void QCA::SASL::authenticated()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
QT_WARNING_POP
